@@ -20,7 +20,7 @@ class board(object):
             :type urls: dict or None
         """
         self.name = name
-        self._https = https
+        self.https = https
         self._urls = urls or fourch.urls
         self._session = requests.Session()
         self._session.headers.update({"User-Agent": "fourch/{0} (@https://github.com/plausibility/4ch)".format(fourch.__version__)})
@@ -38,17 +38,24 @@ class board(object):
             :return: the protocol to use
             :rtype: str
         """
-        return "https://" if self._https else "http://"
+        return "https://" if self.https else "http://"
 
-    def https(self, s):
-        """ Set the HTTPS variable, allowing dynamic changes to https or http urls.
-
-            :param s: the new https boolean
-            :type s: bool
+    def catalog(self):
+        """ Get a list of all the thread OPs and last replies.
         """
-        if not isinstance(s, bool):
-            return
-        self._https = s
+        url = self._base_url + self._urls["api_catalog"].format(board=self.name)
+        r = self._session.get(url)
+        return r.json()
+
+    def threads(self):
+        """ Get a list of all the threads alive, and which page they're on.
+
+            You can cross-reference this with a threads number to see which page
+            it's on at the time of calling.
+        """
+        url = self._base_url + self._urls["api_threads"].format(board=self.name)
+        r = self._session.get(url)
+        return r.json()
 
     def thread(self, res, update_cache=True):
         """ Create a :class:`fourch.thread` object.
@@ -75,9 +82,9 @@ class board(object):
             self._cache[res] = t
         return t
 
-    def page(self, page=0, update_each=False):
+    def page(self, page=1, update_each=False):
         """ Return all the threads in a single page.
-            The page number is zero-indexed. The first page is 0, second is 1, etc.
+            The page number is now one-indexed. The first page is 1, second is 2, etc.
 
             If a thread has already been cached, return the cache entry rather than making a new thread.
 
